function [ch]=character(ahan, type, pos, color)
%[CHAN] = CHARACTER(AHAN, TYPE, POS, COLOR)
%   
%   Creates character object, and renders it.
%   Inputs:
%       AHAN:  [1x1 double]     %axis handle
%       TYPE:  {'pacman'|'ghost'|'bghost'|'bbghost'|'eyes'}
%       POS:   [1x1 node object]
%       COLOR: {'red'|'pink'|'cyan'|'orange'}
%           Note: color input is not required for 'pacman'
%           type.
%   Outputs:
%       CHAN:   [1x1 character object]
%           Acts as a gaphics handle to character object


%check that number of inputs doesn't not exceed 3
%and is not under 2
if nargin < 2
    error('Not enough input arguments.')
end

%checks for valid input types
if isa(ahan, 'double') & ishandle(ahan)
    if get(ahan, 'type')~='axis'
        error('Invalid axis handle.  Character needs to be associated with an axis.')
    end
else
    error('Invalid axis handle.  Character must be associate with an axis.')
end

if ~strcmp(type,'pacman') & ~strcmp(type,'ghost') & ~strcmp(type,'bghost') & ~strcmp(type,'eyes')
    error('Invalid character type.')
end

if class(pos) ~= 'node'
    error('Invalid position class.  Character position must be of class ''node''.')
else
    pos = get(pos, 'position');
end

if ~strcmp(type,'pacman')
    if (nargin == 4) & (~strcmp(color,'red') & ~strcmp(color,'pink') & ~strcmp(color,'cyan') & ~strcmp(color,'orange'))
        error('Invalid character color.')
    elseif nargin == 3
        s = sprintf('Need specify color for type ''%s''.', type);
        error(s)
    end
end


%grab data....
corn = corners(ahan,pos);  %get the corners of image based on position and nodesize
pdata = getappdata(ahan, type);

%Begin switch case for different character types
switch type
    case 'pacman'
        
        %render character
        p.graphics = image(corn{:}, pdata(1).left.pxl, 'alphadata', pdata(1).left.alpha);
        
        %construct structure for pacman
        p.direction = 'left';
        p.currentdir = 'left';
        color = [1 0 0];
        
        %store pacman sound
        [y, fs] = wavread('sounds/eating.short.wav');
        p.sound{1}=y(1:round(0.5*length(y)));
        p.sound{2}=y(round(0.5*length(y)):end);
        p.sound{3}=fs;
        
    case 'ghost'
        
        %get level and node dimension
        lev = getappdata(gca, 'level');         %get level matrix
        nodedim = get(lev, 'nodedim');
        
        %grab eye data
        eyedata = getappdata(ahan, 'eyes');
        
        %render character
        S.type = '.';
        S.subs = color;
        cdata = subsref(pdata(1),S);
        alphadata = cdata.alpha;
        cdata = cdata.pxl .* eyedata.up.sockets + eyedata.up.pxl;
        p.graphics = image(corn{1}-0.5*nodedim, corn{2}, cdata, 'alphadata', alphadata);
        
        p.direction = 'up';
        p.currentdir = 'up';
        
        %store ghost sound
        [y, fs] = wavread('sounds/siren.wav');
        p.sound{1}=y(1:round(0.125*length(y)));
        p.sound{2}=y(round(0.125*length(y)):round(0.25*length(y)));
        p.sound{3}=fs;
        
    case 'bghost'   %blue ghost
        %assume never 'create' one of these.
        %assume that ghost only 'changes' to these in game
    case 'bbghost'
        %this is just like the blue ghost except it blinks
        %warning of its return to regular color.
        %Also assume never create one of these.
    case 'eyes'
        %ditto
end

%set generic object data
p.type = type;
p.node = pos;
p.color = color;
p.visible = 'on';
p.animation = 1;

%create object
ch = class(p, 'character');