function [A, alpha] = makeimage(C, varargin)
%   creates an 'image' matrix to be used with IMAGE.
%   A = makeimage(C, color1, color2, color3,...)
%   C is an MxN matrix of integers corresponding to colors specified
%   color1, color2, etc. are 1x3 double arrays of RGB colors.
%   A is a MxNx3 matrix to be used with the IMAGE command
%   where the third dimension is filled with colors specified
%
%   [A, ALPHA] = makeimage(C, color1, color2,...) also returns the
%   Alpha data for the matrix.  ALPHA will be an MxN matrix, that will
%   contain mostly 1's.  It will have a zero everywhere there was a 
%   zero in the C matrix.
%
%   example:
%   C = [1 2 3; 
%        3 3 1];
%   color1 = [0 0 0];
%   color2 = [1 1 0];
%   color3 = [0 0 0.5];
%   A = makeimage(C, color1, color2, color3);
%       this returns a 2x3x3 matrix.  A(1,1,:) will be [0 0 0]
%       and A(2,2,:) will be [0 0 0.5]

%check to see that input matrix is double
if ~strcmp(class(C),'double') & ~strcmp(class(C),'uint8')
    error('Input must be of class double')
end

%check that C is 2D
if ndims(C)>2
    error('Input must only have two dimensions');
end

%check that all elements in C are integers
if round(C)~=C
    error('Input cannot contain elements other than integers')
end

%checks to see if there is a bigger number in the matrix than
%the number of colors
if (max(max(C))>(nargin-1))
    error('Not enough colors specified')
end

A = zeros(prod(size(C)),3);     %create empty (M*N)x3 array
for ii=1:(nargin-1)     %cycle through all colors
    where = find(C==ii);    %find where colors are located
    for jj=1:length(where)  %cycle through all locations of current color
        A(where(jj),:)=varargin{ii};    %place color at that location
    end
end
A = reshape(A,[size(C) 3]);     %reshape to MxNx3

alpha = ones(size(C));      %create MxN matrix of ones
where = find(C==0);         %find where C has zeros
for ii=1:length(where)      %cycle through all locations of zeros
    alpha(where(ii))=0;     %make alpha zero
end